Crate is_sudo

Crate is_sudo 

Enums

RunningAs
Cross platform representation of the state the current program running

Functions

check
This checks whether the current process is running as sudo or not. Returns the RunningAs enum as result