Crate is_sudo
is_sudo
0.0.2
All Items
Crate Items
Enums
Functions
Crate
is_sudo
Enums

Running
As
Cross platform representation of the state the current program running
Functions

check
This checks whether the current process is running as sudo or not. Returns the RunningAs enum as result